@@ -205,12 +205,6 @@ class dyn_obj:
         name = self.name+'_streamline'
         frames = self.frames
 
-        #introduce a little jitter to allow the "Build" animation to work properly in blender
-        int_x[np.where(np.diff(int_x) == 0)[0] + 1] = np.random.rand(len(int_x))*.00001*min(int_x) + int_x[np.where(np.diff(int_x) == 0)[0] + 1]
-        int_y[np.where(np.diff(int_y) == 0)[0] + 1] = np.random.rand(len(int_y))*.00001*min(int_y) + int_y[np.where(np.diff(int_y) == 0)[0] + 1]
-        int_z[np.where(np.diff(int_z) == 0)[0] + 1] = np.random.rand(len(int_z))*.00001*min(int_z) + int_z[np.where(np.diff(int_z) == 0)[0] + 1]
-
-
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
         int_coords[:, 0] = int_x*self.scale
