@@ -46,7 +46,7 @@ def erase_vector(name):
             
     [bpy.data.objects.remove(bpy.data.objects[obj_name]) for obj_name in obj_list]
 
-def erase_sef(obj_name):
+def erase_self(obj_name):
     """
         Erase object from name passed
 
